@@ -23,7 +23,6 @@ from typing import Iterator, List, Tuple
 from absl import app
 from absl import flags
 from absl import logging
-
 from capirca.lib import aclgenerator
 from capirca.lib import arista
 from capirca.lib import arista_tp
@@ -41,9 +40,11 @@ from capirca.lib import iptables
 from capirca.lib import juniper
 from capirca.lib import junipermsmpc
 from capirca.lib import junipersrx
+from capirca.lib import k8s
 from capirca.lib import naming
 from capirca.lib import nftables
 from capirca.lib import nsxv
+from capirca.lib import openconfig
 from capirca.lib import packetfilter
 from capirca.lib import paloaltofw
 from capirca.lib import pcap
@@ -51,7 +52,6 @@ from capirca.lib import policy
 from capirca.lib import speedway
 from capirca.lib import srxlo
 from capirca.lib import windows_advfirewall
-
 from capirca.utils import config
 
 FLAGS = flags.FLAGS
@@ -179,6 +179,7 @@ def RenderFile(base_directory: str, input_file: pathlib.Path,
   msmpc = False
   spd = False
   nsx = False
+  oc = False
   pcap_accept = False
   pcap_deny = False
   pf = False
@@ -189,6 +190,7 @@ def RenderFile(base_directory: str, input_file: pathlib.Path,
   nxacl = False
   xacl = False
   paloalto = False
+  k8s_pol = False
 
   try:
     with open(input_file) as f:
@@ -238,6 +240,8 @@ def RenderFile(base_directory: str, input_file: pathlib.Path,
     msmpc = copy.deepcopy(pol)
   if 'nsxv' in platforms:
     nsx = copy.deepcopy(pol)
+  if 'openconfig' in platforms:
+    oc = copy.deepcopy(pol)
   if 'packetfilter' in platforms:
     pf = copy.deepcopy(pol)
   if 'pcap' in platforms:
@@ -265,6 +269,8 @@ def RenderFile(base_directory: str, input_file: pathlib.Path,
     paloalto = copy.deepcopy(pol)
   if 'cloudarmor' in platforms:
     gca = copy.deepcopy(pol)
+  if 'k8s' in platforms:
+    k8s_pol = copy.deepcopy(pol)
 
   acl_obj: aclgenerator.ACLGenerator
 
@@ -329,6 +335,11 @@ def RenderFile(base_directory: str, input_file: pathlib.Path,
       RenderACL(
           str(acl_obj), acl_obj.SUFFIX, output_directory, input_file,
           write_files)
+    if oc:
+      acl_obj = openconfig.OpenConfig(oc, exp_info)
+      RenderACL(
+          str(acl_obj), acl_obj.SUFFIX, output_directory, input_file,
+          write_files)
     if spd:
       acl_obj = speedway.Speedway(spd, exp_info)
       RenderACL(
@@ -395,6 +406,13 @@ def RenderFile(base_directory: str, input_file: pathlib.Path,
       RenderACL(
           str(acl_obj), acl_obj.SUFFIX, output_directory, input_file,
           write_files)
+
+    if k8s_pol:
+      acl_obj = k8s.K8s(k8s_pol, exp_info)
+      RenderACL(
+          str(acl_obj), acl_obj.SUFFIX, output_directory, input_file,
+          write_files)
+
   # TODO(robankeny) add additional errors.
   except (
       juniper.Error,
@@ -409,7 +427,8 @@ def RenderFile(base_directory: str, input_file: pathlib.Path,
       aruba.Error,
       nftables.Error,
       gce.Error,
-      cloudarmor.Error) as e:
+      cloudarmor.Error,
+      k8s.Error) as e:
     raise ACLGeneratorError('Error generating target ACL for %s:\n%s' %
                             (input_file, e))
 
