@@ -135,7 +135,8 @@ class Term(aclgenerator.Term):
              'reject': 'reject',
              'next': 'next term',
              'reject-with-tcp-rst': 'reject tcp-reset',
-             'encapsulate': 'encapsulate'}
+             'encapsulate': 'encapsulate',
+             'port-mirror': 'port-mirror'}
 
   # the following lookup table is used to map between the various types of
   # filters the juniper generator can render.  As new differences are
@@ -556,10 +557,12 @@ class Term(aclgenerator.Term):
     if self.term.encapsulate:
       unique_actions.add('encapsulate')
     if len(unique_actions) <= 1:
-      for action in [self.term.logging, self.term.routing_instance,
-                     self.term.counter, self.term.policer, self.term.qos,
-                     self.term.loss_priority, self.term.dscp_set,
-                     self.term.next_ip, self.term.traffic_class_count]:
+      for action in [
+          self.term.logging, self.term.routing_instance, self.term.counter,
+          self.term.policer, self.term.qos, self.term.loss_priority,
+          self.term.dscp_set, self.term.next_ip, self.term.traffic_class_count,
+          self.term.port_mirror
+      ]:
         if action:
           try:
             unique_actions.update(action)
@@ -630,6 +633,8 @@ class Term(aclgenerator.Term):
       if self.term.qos:
         config.Append('forwarding-class %s;' % self.term.qos)
 
+      if self.term.port_mirror:
+        config.Append('port-mirror;')
       if self.term.loss_priority:
         config.Append('loss-priority %s;' % self.term.loss_priority)
       if self.term.next_ip:
@@ -899,6 +904,7 @@ class Juniper(aclgenerator.ACLGenerator):
                          'packet_length',
                          'policer',
                          'port',
+                         'port_mirror',
                          'precedence',
                          'protocol_except',
                          'qos',
@@ -939,11 +945,14 @@ class Juniper(aclgenerator.ACLGenerator):
       interface_specific = 'not-interface-specific' not in filter_options[1:]
       enable_dsmo = 'enable_dsmo' in filter_options[1:]
       noverbose = 'noverbose' in filter_options[1:]
+      filter_enhanced_mode = 'filter_enhanced_mode' in filter_options[1:]
 
       if not interface_specific:
         filter_options.remove('not-interface-specific')
       if enable_dsmo:
         filter_options.remove('enable_dsmo')
+      if filter_enhanced_mode:
+        filter_options.remove('filter_enhanced_mode')
 
       # default to inet4 filters
       filter_type = 'inet'
@@ -1004,12 +1013,12 @@ class Juniper(aclgenerator.ACLGenerator):
           new_terms.append(self._TERM(term, filter_type, enable_dsmo, noverbose))
 
         self.juniper_policies.append((header, filter_name + filter_name_suffix, filter_type,
-                                      interface_specific, new_terms))
+                                      interface_specific, filter_enhanced_mode, new_terms))
 
   def __str__(self):
     config = Config()
 
-    for (header, filter_name, filter_type, interface_specific, terms
+    for (header, filter_name, filter_type, interface_specific, filter_enhanced_mode, terms
         ) in self.juniper_policies:
       # add the header information
       config.Append('firewall {')
@@ -1032,6 +1041,8 @@ class Juniper(aclgenerator.ACLGenerator):
       config.Append('replace: filter %s {' % filter_name)
       if interface_specific:
         config.Append('interface-specific;')
+      if filter_enhanced_mode:
+        config.Append('enhanced-mode;')
 
       for term in terms:
         term_str = str(term)
